==> ejc-jltest-api-3.0.0-20240321.001859-91-sources.jar: com/ejianc/business/jltest/margin/vo/InspiritLossVO.java <==
package com.ejianc.business.jltest.margin.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.jltest.margin.vo.InspiritLossDetailVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 激励/补亏分配详情
 *
 * @author generator
 *
 */
public class InspiritLossVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String billCode; // 激励补亏分配编号
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private Date belongsTime; // 所属年度
    private Long standardId; // 标准表
    private String standardName; // 标准表名称
    private String standardCode; // 标准表code
    private Long cashId; // 兑现审批表
    private String cashName; // 兑现审批表名称
    private String cashCode; // 兑现审批表code
    private BigDecimal cashMny; //  考核兑现金额
    private BigDecimal issueAssessMny; //  本期分配总金额
    private BigDecimal issueAssessSumMny; //  本期分配总金额
    private String cashNode; //  绩效激励/补亏节点
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private String projectCode; // 项目code
    private Long orgId; // 组织
    private String orgName; // 组织名称
    private String orgCode; // 组织code
    private String parentOrgName; //
    private String parentOrgCode; // 父级组织编码
    private Long parentOrgId; // 父级组织
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    private Long departmentId; // 经办部门
    private String departmentName; // 经办部门名称
    private String memo; // 备注
    private Integer billState; // 单据状态（审批必须字段）

    public BigDecimal getIssueAssessSumMny() {
        return issueAssessSumMny;
    }

    public void setIssueAssessSumMny(BigDecimal issueAssessSumMny) {
        this.issueAssessSumMny = issueAssessSumMny;
    }

    private List<InspiritLossDetailVO> inspiritLossDetailList = new ArrayList<>(); // 激励补亏分配详情明细

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Date getBelongsTime() {
        return belongsTime;
    }

    public void setBelongsTime(Date belongsTime) {
        this.belongsTime = belongsTime;
    }
    public Long getStandardId() {
        return standardId;
    }

    public void setStandardId(Long standardId) {
        this.standardId = standardId;
    }
    public String getStandardName() {
        return standardName;
    }

    public void setStandardName(String standardName) {
        this.standardName = standardName;
    }
    public String getStandardCode() {
        return standardCode;
    }

    public void setStandardCode(String standardCode) {
        this.standardCode = standardCode;
    }
    @ReferSerialTransfer(referCode = "assess-cash")
    public Long getCashId() {
        return cashId;
    }
    @ReferDeserialTransfer

    public void setCashId(Long cashId) {
        this.cashId = cashId;
    }
    public String getCashName() {
        return cashName;
    }

    public void setCashName(String cashName) {
        this.cashName = cashName;
    }
    public String getCashCode() {
        return cashCode;
    }

    public void setCashCode(String cashCode) {
        this.cashCode = cashCode;
    }
    public BigDecimal getCashMny() {
        return cashMny;
    }

    public void setCashMny(BigDecimal cashMny) {
        this.cashMny = cashMny;
    }
    public BigDecimal getIssueAssessMny() {
        return issueAssessMny;
    }

    public void setIssueAssessMny(BigDecimal issueAssessMny) {
        this.issueAssessMny = issueAssessMny;
    }
    public String getCashNode() {
        return cashNode;
    }

    public void setCashNode(String cashNode) {
        this.cashNode = cashNode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    @ReferSerialTransfer(referCode="idm-dept")
    public Long getDepartmentId() {
        return departmentId;
    }
    @ReferDeserialTransfer
    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

     public List<InspiritLossDetailVO> getInspiritLossDetailList() {
        return inspiritLossDetailList;
     }

     public void setInspiritLossDetailList(List<InspiritLossDetailVO> inspiritLossDetailList) {
        this.inspiritLossDetailList = inspiritLossDetailList;
     }
}

==> ejc-jltest-api-3.0.0-20240330.015139-147-sources.jar: com/ejianc/business/jltest/margin/vo/InspiritLossVO.java <==
package com.ejianc.business.jltest.margin.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

import com.ejianc.business.jltest.margin.vo.InspiritLossDetailVO;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 激励/补亏分配详情
 *
 * @author generator
 *
 */
public class InspiritLossVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private String billCode; // 激励补亏分配编号

    private Long belongsTime; // 所属年度
    private Long standardId; // 标准表
    private String standardName; // 标准表名称
    private String standardCode; // 标准表code
    private Long cashId; // 兑现审批表
    private String cashName; // 兑现审批表名称
    private String cashCode; // 兑现审批表code
    private BigDecimal cashMny; //  考核兑现金额
    private BigDecimal issueAssessMny; //  本期分配总金额
    private BigDecimal issueAssessSumMny; //  本期分配总金额
    private BigDecimal issueAssessHistoryMny;//历史分配金额
    private String cashNode; //  绩效激励/补亏节点
    private Long projectId; // 项目
    private String projectName; // 项目名称
    private String projectCode; // 项目code
    private Long orgId; // 组织
    private String orgName; // 组织名称
    private String orgCode; // 组织code
    private String parentOrgName; //
    private String parentOrgCode; // 父级组织编码
    private Long parentOrgId; // 父级组织
    private Long employeeId; // 经办人
    private String employeeName; // 经办人名称
    private Long departmentId; // 经办部门
    private String departmentName; // 经办部门名称
    private String memo; // 备注
    private Integer billState; // 单据状态（审批必须字段）

    public BigDecimal getIssueAssessSumMny() {
        return issueAssessSumMny;
    }

    public void setIssueAssessSumMny(BigDecimal issueAssessSumMny) {
        this.issueAssessSumMny = issueAssessSumMny;
    }

    private List<InspiritLossDetailVO> inspiritLossDetailList = new ArrayList<>(); // 激励补亏分配详情明细

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Long getBelongsTime() {
        return belongsTime;
    }

    public void setBelongsTime(Long belongsTime) {
        this.belongsTime = belongsTime;
    }

    public BigDecimal getIssueAssessHistoryMny() {
        return issueAssessHistoryMny;
    }

    public void setIssueAssessHistoryMny(BigDecimal issueAssessHistoryMny) {
        this.issueAssessHistoryMny = issueAssessHistoryMny;
    }

    public Long getStandardId() {
        return standardId;
    }

    public void setStandardId(Long standardId) {
        this.standardId = standardId;
    }
    public String getStandardName() {
        return standardName;
    }

    public void setStandardName(String standardName) {
        this.standardName = standardName;
    }
    public String getStandardCode() {
        return standardCode;
    }

    public void setStandardCode(String standardCode) {
        this.standardCode = standardCode;
    }
    @ReferSerialTransfer(referCode = "assess-cash")
    public Long getCashId() {
        return cashId;
    }
    @ReferDeserialTransfer

    public void setCashId(Long cashId) {
        this.cashId = cashId;
    }
    public String getCashName() {
        return cashName;
    }

    public void setCashName(String cashName) {
        this.cashName = cashName;
    }
    public String getCashCode() {
        return cashCode;
    }

    public void setCashCode(String cashCode) {
        this.cashCode = cashCode;
    }
    public BigDecimal getCashMny() {
        return cashMny;
    }

    public void setCashMny(BigDecimal cashMny) {
        this.cashMny = cashMny;
    }
    public BigDecimal getIssueAssessMny() {
        return issueAssessMny;
    }

    public void setIssueAssessMny(BigDecimal issueAssessMny) {
        this.issueAssessMny = issueAssessMny;
    }
    public String getCashNode() {
        return cashNode;
    }

    public void setCashNode(String cashNode) {
        this.cashNode = cashNode;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }
    @ReferSerialTransfer(referCode = "idm-org")
    public Long getOrgId() {
        return orgId;
    }
    @ReferDeserialTransfer
    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }
    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }
    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    @ReferSerialTransfer(referCode = "idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }
    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
    public String getEmployeeName() {
        return employeeName;
    }

    public void setEmployeeName(String employeeName) {
        this.employeeName = employeeName;
    }
    @ReferSerialTransfer(referCode="idm-dept")
    public Long getDepartmentId() {
        return departmentId;
    }
    @ReferDeserialTransfer
    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }

     public List<InspiritLossDetailVO> getInspiritLossDetailList() {
        return inspiritLossDetailList;
     }

     public void setInspiritLossDetailList(List<InspiritLossDetailVO> inspiritLossDetailList) {
        this.inspiritLossDetailList = inspiritLossDetailList;
     }
}
